declare const __parsed_brand: unique symbol;
export type Brand<T, B> = T & {
    [__parsed_brand]: B;
};
export type Parser<T> = (value: unknown) => T;
export type ParsedFrom<T extends Parser<unknown>> = ReturnType<T>;
export declare class ParseError extends Error {
    name: string;
    shape: string;
}
export declare class ParseTypeMismatch extends ParseError {
    name: string;
    constructor(expectedType: string, receivedValue: unknown);
}
export declare class ParseValueInvalid extends ParseError {
    name: string;
    constructor(expectedType: string, recievedValue: unknown);
}
export declare const Parse: {
    readonly unknown: (val: unknown) => unknown;
    readonly number: (val: unknown) => number;
    readonly string: (val: unknown) => string;
    readonly boolean: (val: unknown) => boolean;
    readonly bigint: (val: unknown) => bigint;
    readonly symbol: (val: unknown) => symbol;
    readonly null: (val: unknown) => null;
    readonly undefined: (val: unknown) => undefined;
    readonly array: (val: unknown) => unknown[];
    readonly arrayOf: <T>(parser: (val: unknown) => T, val: unknown) => T[];
    readonly shape: <T extends Record<string, Parser<any>>>(parsers: T, val: unknown) => { [K in keyof T]: ReturnType<T[K]>; };
    readonly regex: <T extends string>(regex: RegExp, val: unknown) => T;
    readonly enum: <E extends string>(enumDef: readonly E[], val: unknown) => E;
};
export declare const ParserFor: {
    readonly shape: <T extends Record<string, Parser<any>>>(parsers: T, shapeName?: string) => (val: unknown) => { [K in keyof T]: ReturnType<T[K]>; };
    readonly enum: <E extends string>(enumDef: readonly E[], shapeName?: string) => (val: unknown) => E;
    readonly regex: <T extends string>(regex: RegExp, shapeName?: string) => (val: unknown) => T;
    readonly arrayOf: <T>(parser: (val: unknown) => T, shapeName?: string) => (val: unknown) => T[];
};
export {};
